from pydantic_settings import BaseSettings
import os


class Settings(BaseSettings):
    app_name: str = "Cryptocurrency Exchange Platform"
    app_version: str = "1.0.0"
    debug: bool = True
    
    # Security
    secret_key: str = os.getenv("SECRET_KEY", "your-secret-key-change-in-production")
    algorithm: str = "HS256"
    access_token_expire_minutes: int = 30
    
    # Database
    database_url: str = "sqlite:////app/storage/db/db.sqlite"
    
    # CORS
    allowed_origins: list = ["*"]
    
    # Crypto settings
    btc_network: str = "testnet"  # mainnet or testnet
    eth_network: str = "goerli"   # mainnet or goerli
    
    # Fiat settings
    min_fiat_deposit: float = 10.0
    max_fiat_deposit: float = 10000.0
    min_fiat_withdrawal: float = 10.0
    max_fiat_withdrawal: float = 5000.0
    
    class Config:
        env_file = ".env"


settings = Settings()