from sqlalchemy import Column, Integer, String, Float, DateTime, ForeignKey, Text, Enum
from sqlalchemy.sql import func
from sqlalchemy.orm import relationship
import enum
from app.db.base import Base


class TransactionStatus(enum.Enum):
    PENDING = "pending"
    CONFIRMED = "confirmed"
    FAILED = "failed"
    CANCELLED = "cancelled"


class TransactionType(enum.Enum):
    SEND = "send"
    RECEIVE = "receive"
    DEPOSIT = "deposit"
    WITHDRAWAL = "withdrawal"


class Transaction(Base):
    __tablename__ = "transactions"

    id = Column(Integer, primary_key=True, index=True)
    user_id = Column(Integer, ForeignKey("users.id"), nullable=False)
    from_wallet_id = Column(Integer, ForeignKey("wallets.id"), nullable=True)
    to_wallet_id = Column(Integer, ForeignKey("wallets.id"), nullable=True)
    
    transaction_hash = Column(String, unique=True, nullable=True)
    amount = Column(Float, nullable=False)
    fee = Column(Float, default=0.0)
    currency = Column(String, nullable=False)
    
    transaction_type = Column(Enum(TransactionType), nullable=False)
    status = Column(Enum(TransactionStatus), default=TransactionStatus.PENDING)
    
    from_address = Column(String, nullable=True)
    to_address = Column(String, nullable=False)
    
    block_number = Column(Integer, nullable=True)
    confirmations = Column(Integer, default=0)
    
    notes = Column(Text, nullable=True)
    created_at = Column(DateTime(timezone=True), server_default=func.now())
    updated_at = Column(DateTime(timezone=True), onupdate=func.now())
    
    # Relationships
    user = relationship("User", back_populates="transactions")
    from_wallet = relationship("Wallet", foreign_keys=[from_wallet_id], back_populates="transactions_sent")
    to_wallet = relationship("Wallet", foreign_keys=[to_wallet_id], back_populates="transactions_received")


class FiatTransaction(Base):
    __tablename__ = "fiat_transactions"

    id = Column(Integer, primary_key=True, index=True)
    account_id = Column(Integer, ForeignKey("fiat_accounts.id"), nullable=False)
    
    amount = Column(Float, nullable=False)
    currency = Column(String, nullable=False)
    transaction_type = Column(Enum(TransactionType), nullable=False)
    status = Column(Enum(TransactionStatus), default=TransactionStatus.PENDING)
    
    bank_reference = Column(String, nullable=True)
    payment_method = Column(String, nullable=True)  # bank_transfer, card, etc.
    
    notes = Column(Text, nullable=True)
    created_at = Column(DateTime(timezone=True), server_default=func.now())
    updated_at = Column(DateTime(timezone=True), onupdate=func.now())
    
    # Relationships
    account = relationship("FiatAccount", back_populates="deposits")