from sqlalchemy import Column, Integer, String, Boolean, DateTime
from sqlalchemy.sql import func
from sqlalchemy.orm import relationship
from app.db.base import Base


class User(Base):
    __tablename__ = "users"

    id = Column(Integer, primary_key=True, index=True)
    email = Column(String, unique=True, index=True, nullable=False)
    hashed_password = Column(String, nullable=False)
    full_name = Column(String, nullable=False)
    is_active = Column(Boolean, default=True)
    is_verified = Column(Boolean, default=False)
    created_at = Column(DateTime(timezone=True), server_default=func.now())
    updated_at = Column(DateTime(timezone=True), onupdate=func.now())
    
    # KYC fields
    kyc_level = Column(Integer, default=0)  # 0: none, 1: basic, 2: advanced
    phone_number = Column(String, nullable=True)
    country = Column(String, nullable=True)
    
    # Relationships
    wallets = relationship("Wallet", back_populates="owner")
    fiat_accounts = relationship("FiatAccount", back_populates="owner")
    transactions = relationship("Transaction", back_populates="user")