from sqlalchemy import Column, Integer, String, Float, Boolean, DateTime, ForeignKey
from sqlalchemy.sql import func
from sqlalchemy.orm import relationship
from app.db.base import Base


class Wallet(Base):
    __tablename__ = "wallets"

    id = Column(Integer, primary_key=True, index=True)
    user_id = Column(Integer, ForeignKey("users.id"), nullable=False)
    currency = Column(String, nullable=False)  # BTC, ETH, USDT
    address = Column(String, unique=True, nullable=False)
    private_key_encrypted = Column(String, nullable=False)
    balance = Column(Float, default=0.0)
    is_active = Column(Boolean, default=True)
    created_at = Column(DateTime(timezone=True), server_default=func.now())
    updated_at = Column(DateTime(timezone=True), onupdate=func.now())
    
    # Relationships
    owner = relationship("User", back_populates="wallets")
    transactions_sent = relationship("Transaction", foreign_keys="Transaction.from_wallet_id", back_populates="from_wallet")
    transactions_received = relationship("Transaction", foreign_keys="Transaction.to_wallet_id", back_populates="to_wallet")


class FiatAccount(Base):
    __tablename__ = "fiat_accounts"

    id = Column(Integer, primary_key=True, index=True)
    user_id = Column(Integer, ForeignKey("users.id"), nullable=False)
    currency = Column(String, nullable=False)  # USD, EUR, GBP
    balance = Column(Float, default=0.0)
    is_active = Column(Boolean, default=True)
    created_at = Column(DateTime(timezone=True), server_default=func.now())
    updated_at = Column(DateTime(timezone=True), onupdate=func.now())
    
    # Relationships
    owner = relationship("User", back_populates="fiat_accounts")
    deposits = relationship("FiatTransaction", foreign_keys="FiatTransaction.account_id", back_populates="account")